import gurobipy as gu
import numpy as np


def solve_lp1():

    m = gu.Model("prvni")

    x1 = m.addVar(vtype=gu.GRB.CONTINUOUS, lb=0) # lb=-gu.GRB.INFINITY)
    x2 = m.addVar(vtype=gu.GRB.CONTINUOUS, lb=0)

    m.update()

    m.addConstr(2 * x1 + 5 * x2 <= 20)
    m.addConstr(6 * x1 + x2 <= 15)
    m.addConstr(x2 <= 3.5)

    m.setObjective(2 * x1 + 4 * x2)
    m.modelSense = gu.GRB.MAXIMIZE

    m.optimize()


def solve_lp2():

    c_j = [2, 4]
    b_i = [20, 15, 3.5]
    a_ij = np.array([[2, 5],
            [6, 1],
            [0, 1]])

    nr_j = len(c_j)
    nr_i = len(b_i)

    jrange = range(nr_j)
    irange = range(nr_i)

    m = gu.Model("prvni")

    x_j = np.array([m.addVar(vtype=gu.GRB.CONTINUOUS, lb=0) for j in jrange])
    m.update()

    for i in irange:
        m.addConstr(gu.quicksum(a_ij[i, j] * x_j[j] for j in jrange) <= b_i[i], name="omezeni%i" % i)

    m.setObjective(gu.quicksum(c_j[j] * x_j[j] for j in jrange))
    m.modelSense = gu.GRB.MAXIMIZE

    m.setParam("OutputFlag", 0.0)
    m.optimize()

    if (m.Status == 2):
        results = [x_j[j].x for j in jrange]

        for j in jrange:
            print("x_%i: " % (j + 1), results[j])
        # m.objVal()
        obj = m.getObjective()
        print("ziskame: ", m.objVal)
        print("ziskame: ", obj.getValue())

        for c in m.getConstrs():
            print(c.ConstrName, "DUALNI CENA:", c.Pi)

        for c in m.getConstrs():
            print(c.Slack)

        return results


def control_panel():

    #solve_lp1()
    print("-------------")
    solve_lp2()



if __name__ == "__main__":

    control_panel()
